/*############################################################################
 TabDemo
 Author: Shooter Kennett
 Date: 14 Dec 2010
 Current build: Release Rev 0
 Objective: Build a demo from an existing MASM32 / RadASM 2.x project
	illustrating the use of the Win32 API control, TabStrip.

	typedef struct _TC_ITEM { 
    	UINT mask;         // value specifying which members to retrieve or set 
    	UINT lpReserved1;  // reserved; do not use 
    	UINT lpReserved2;  // reserved; do not use 
    	LPSTR pszText;     // pointer to string containing tab text 
    	int cchTextMax;    // size of buffer pointed to by the pszText member 
    	int iImage;        // index to tab control's image 
    	LPARAM lParam;     // application-defined data associated with tab 
	} TC_ITEM

	The TC_ITEM structure specifies or receives the attributes of a tab. 

	Members:
	mask
		Value specifying which members to retrieve or set. This member can 
		be TCIF_ALL (meaning all members), or zero or more of the following 
		values:

		Value		Meaning
		TCIF_TEXT	The pszText member is valid.
		TCIF_IMAGE	The iImage member is valid.
		TCIF_PARAM	The lParam member is valid. 

	lpReserved1
		Reserved; do not use.

	lpReserved2
		Reserved; do not use.

	pszText
		Pointer to a null-terminated string that contains the tab text if 
		the structure contains information about a tab. If the structure is
		receiving information, this member specifies the address of the 
		buffer that receives the tab text.

	cchTextMax
		Size of the buffer pointed to by the pszText member. If the structure
		is not receiving information, this member is ignored.

	iImage
		Index into the tab control's image list or  - 1 if there is no image
		for the tab.

	lParam
		Application-defined data associated with the tab. If there are more
		or less than 4 bytes of application-defined data per tab, an 
		application must define a structure and use it instead of the TC_ITEM
		structure. The first member of the application-defined structure 
		must be a TC_ITEMHEADER structure.

	This structure is used with the TCM_INSERTITEM, TCM_GETITEM, and 
	TCM_SETITEM messages.
	
##############################################################################

 Immediate Files:
	TabDemo1.asm
	TabDemo1.h
	TabDemo1.rc
 Remote Files:
 	Windows.h
	Commctrl.h

 Editor: RadASM 3.0.0.7g 
 Assembler: GoASM
	Command line: /c /x86
 Resource compiler: GoRC
	Command line: /r
 Linker: GoLink
	Command line: $C $M $R
 Debugger: OllyDbg (Launch from command line, does not work from within
 	RadASM.)
 	Command Line: none
##############################################################################
*/
#include "TabDemo1.h"

DATA SECTION
	hInstance	HANDLE		?
	hWin		HANDLE		?
	hTab		dd			?
	SelTab		dd			?
	
	IDD_DLG1	equ			1000
	IDD_TAB1	equ 		2000
	IDD_TAB2	equ 		3000
	IDD_TAB3	equ 		4000
	
	TabTitle1	db			"Tab1",0
	TabTitle2	db			"Tab2",0
	TabTitle3	db			"Tab3",0
	
	ErrorCapt	db			"TabDemo1 Error",0
	ErrorMsg1	db			"Error initializing the window.",0

CODE SECTION

START:
	invoke GetModuleHandle, 0
	mov [hInstance],eax
	invoke InitCommonControls
	push eax
	push ebx
	push ecx
	push edx
	push edi
	pop edi
	pop edx
	pop ecx
	pop ebx
	pop eax
	invoke DialogBoxParam,[hInstance],IDD_DLG1,0,ADDR DlgProc,0

	invoke ExitProcess,0

DlgProc FRAME hWin,uMsg,wParam,lParam
	LOCAL	ts:TC_ITEM
	
	.WM_INITDIALOG

	cmp D[uMsg],WM_INITDIALOG
	jne >>.WM_COMMAND
		;Create the tabs
		invoke GetDlgItem,[hWin],[IDD_TAB1]
		cmp eax,-1
		je >>.Error
		mov	[hTab],eax
		mov	w[ts.mask],TCIF_TEXT or TCIF_PARAM
		mov	b[ts.lpReserved1],0
		mov	b[ts.lpReserved2],0
		mov	b[ts.iImage],-1

		;Create the tab dialog 1
		invoke CreateDialogParam,[hInstance],IDD_TAB1,[hTab],addr Tab1Proc,0
		;Save the dialog handle
		mov	d[ts.lParam],eax
		push ebx
		mov ebx, addr TabTitle1
		mov	d[ts.pszText],ebx
		pop ebx
		mov	d[ts.cchTextMax],sizeof TabTitle1
		invoke SendMessage,[hTab],TCM_INSERTITEM,0,addr ts

		;Create the tab dialog 2
		invoke CreateDialogParam,[hInstance],IDD_TAB2,[hTab],addr Tab2Proc,0
		;Save the dialog handle
		mov	d[ts.lParam],eax
		push ebx
		mov ebx, addr TabTitle2
		mov d[ts.pszText],ebx
		mov ebx, offset TabTitle2
		mov d[ts.pszText],ebx
		mov ebx, sizeof TabTitle2
		mov d[ts.cchTextMax],ebx
		pop ebx
		invoke SendMessage,[hTab],TCM_INSERTITEM,1,addr ts

		;Create the tab dialog 3
		invoke CreateDialogParam,[hInstance],IDD_TAB3,[hTab],addr Tab3Proc,0
		;Save the dialog handle
		mov	d[ts.lParam],eax
		push ebx
		mov ebx, offset TabTitle3
		mov	d[ts.pszText],ebx
		mov ebx, sizeof TabTitle3
		mov	d[ts.cchTextMax],ebx
		pop ebx
		invoke SendMessage,[hTab],TCM_INSERTITEM,2,addr ts
		jmp >>.EXIT

	.WM_COMMAND
	cmp D[uMsg],WM_COMMAND
	jne >>.WM_NOTIFY
		jmp >>.EXIT
	
	.WM_NOTIFY
	cmp D[uMsg],WM_NOTIFY
	jne >>.WM_CLOSE
		mov	eax,[lParam]
		mov	eax,[eax+NMHDR.code]
		cmp eax,TCN_SELCHANGE
		jne >>.WM_CLOSE
			;Tab selection
			invoke SendMessage,[hTab],TCM_GETCURSEL,0,0
			cmp eax, [SelTab]
			jne >>.WM_CLOSE
				push eax
				mov	w[ts.mask],TCIF_TEXT
				invoke SendMessage,[hTab],TCM_GETITEM,[SelTab],addr ts
				invoke ShowWindow,[ts.lParam],SW_HIDE
				pop	eax
				mov	[SelTab],eax
				invoke SendMessage,[hTab],TCM_GETITEM,[SelTab],addr ts
				invoke ShowWindow,[ts.lParam],SW_SHOWDEFAULT
		jmp >>.EXIT

	.WM_CLOSE
	cmp D[uMsg],WM_CLOSE
	jne >>.DEFPROC
		INVOKE EndDialog,[hWin],0

	.DEFPROC
		mov eax,FALSE
		ret
	.Error
	invoke MessageBox [hWin],addr ErrorMsg1,addr ErrorCapt, MB_OK
	invoke EndDialog,[hWin],0
	.EXIT

	mov eax, TRUE
	ret
ENDF
Tab1Proc FRAME hWin,uMsg,wParam,lParam

	cmp D[uMsg],WM_INITDIALOG
	jne >.EndTab1Proc
		mov	eax,FALSE
		ret
	.EndTab1Proc
	mov	eax,TRUE
	ret

endf

Tab2Proc FRAME hWin,uMsg,wParam,lParam

	cmp D[uMsg],WM_INITDIALOG
	jne >.EndTab2Proc
		mov	eax,FALSE
		ret
	.EndTab2Proc
	mov	eax,TRUE
	ret

endf
	
Tab3Proc FRAME hWin,uMsg,wParam,lParam

	cmp D[uMsg],WM_INITDIALOG
	jne >.EndTab3Proc
		mov	eax,FALSE
		ret
	.EndTab3Proc
	mov	eax,TRUE
	ret

endf
